]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - db.h
rename struct dbtool to audio_file_selector
[paraslash.git] / db.h
diff --git a/db.h b/db.h
index cf55b46ff621d789e4eb6d67eb28d6cf793ac08c..bd37d2b45984226dc890f06976924eaa48774702 100644 (file)
--- a/db.h
+++ b/db.h
@@ -33,7 +33,7 @@ int find_audio_files(const char *dirname, int (*f)(const char *, const char *));
  *
  *
  */
  *
  *
  */
-struct dbtool {
+struct audio_file_selector {
 /**
  * name name of this database tool
  */
 /**
  * name name of this database tool
  */
@@ -49,13 +49,13 @@ const char *name;
  * again via the cdt command).
  *
  * If \a init() returns success (non-negative return value), it must have
  * again via the cdt command).
  *
  * If \a init() returns success (non-negative return value), it must have
* initialized in all non-optional function pointers of the given dbtool
  * struct. Moreover, \a cmd_list must point to a NULL-terminated array which
  * holds the list of all commands that are supported by this database tool.
  */
  * struct. Moreover, \a cmd_list must point to a NULL-terminated array which
  * holds the list of all commands that are supported by this database tool.
  */
-int (*init)(struct dbtool *self);
+int (*init)(struct audio_file_selector *self);
 /**
 /**
* list of commands supported by this dbtool
  */
 struct server_command *cmd_list;
 /**
  */
 struct server_command *cmd_list;
 /**
@@ -96,7 +96,7 @@ void (*shutdown)(void);
  * add file descriptors to fd_sets
  *
  * The pre_select function of the activated database tool gets called just
  * add file descriptors to fd_sets
  *
  * The pre_select function of the activated database tool gets called just
* before para_server enters its main select loop. The dbtool may add its own
  * file descriptors to the \a rfds or the \a wfds set.
  *
  * If a file descriptor was added, \a max_fileno must be increased by
  * file descriptors to the \a rfds or the \a wfds set.
  *
  * If a file descriptor was added, \a max_fileno must be increased by
@@ -114,11 +114,11 @@ int (*pre_select)(fd_set *rfds, fd_set *wfds);
  */
 void (*post_select)(fd_set *rfds, fd_set *wfds);
 /**
  */
 void (*post_select)(fd_set *rfds, fd_set *wfds);
 /**
* each dbtool has its private data pointer */
 void *private_data;
 };
 
 void *private_data;
 };
 
-int mysql_dbtool_init(struct dbtool*);
-int plm_dbtool_init(struct dbtool*);
-int random_dbtool_init(struct dbtool*);
+int mysql_dbtool_init(struct audio_file_selector*);
+int plm_dbtool_init(struct audio_file_selector*);
+int random_dbtool_init(struct audio_file_selector*);
@@ -49,13 +49,13 @@ const char *name;
  *
  * If \a init() returns success (non-negative return value), it must have
- * initialized in all non-optional function pointers of the given dbtool
+ * initialized in all non-optional function pointers of the given selector
  * struct. Moreover, \a cmd_list must point to a NULL-terminated array which
  * holds the list of all commands that are supported by this database tool.
@@ -49,13 +49,13 @@ const char *name;
 /**
 /**
- * list of commands supported by this dbtool
+ * list of commands supported by this selector
  */
 struct server_command *cmd_list;
@@ -96,7 +96,7 @@ void (*shutdown)(void);
  *
  * The pre_select function of the activated database tool gets called just
- * before para_server enters its main select loop. The dbtool may add its own
+ * before para_server enters its main select loop. The selector may add its own
  * file descriptors to the \a rfds or the \a wfds set.
  *
@@ -114,11 +114,11 @@ int (*pre_select)(fd_set *rfds, fd_set *wfds);
 void (*post_select)(fd_set *rfds, fd_set *wfds);
 /**
- * each dbtool has its private data pointer */
+ * each selector has its private data pointer */
 void *private_data;
 };